@@ -56,6 +56,12 @@ typedef enum {
 	PHONEMGR_LISTENER_CALL_UNKNOWN
 } PhonemgrListenerCallStatus;
 
+typedef enum {
+	PHONEMGR_LISTENER_DATA_CONTACT,
+	PHONEMGR_LISTENER_DATA_CALENDAR,
+	PHONEMGR_LISTENER_DATA_TODO
+} PhonemgrListenerDataType;
+
 #define CALL_NAME_UNKNOWN "Unknown"
 #define CALL_NAME_RESTRICTED "Withheld"
 
@@ -77,7 +83,7 @@ GQuark phonemgr_listener_error_quark	(void) G_GNUC_CONST;
 GType	phonemgr_listener_get_type	(void);
 PhonemgrListener* phonemgr_listener_new	(gboolean debug);
 gboolean phonemgr_listener_connect	(PhonemgrListener *listener,
-					 char *device,
+					 const char *device,
 					 GError **error);
 void phonemgr_listener_disconnect	(PhonemgrListener *listener);
 void phonemgr_listener_queue_message	(PhonemgrListener *listener,
@@ -89,6 +95,19 @@ void phonemgr_listener_answer_call	(PhonemgrListener *l);
 void phonemgr_listener_set_time		(PhonemgrListener *l,
 					 time_t time);
 
+char ** phonemgr_listener_list_all_data
+					(PhonemgrListener *l,
+					 PhonemgrListenerDataType type);
+char * phonemgr_listener_get_data	(PhonemgrListener *l,
+					 PhonemgrListenerDataType type,
+					 const char *dataid);
+gboolean phonemgr_listener_delete_data	(PhonemgrListener *l,
+					 PhonemgrListenerDataType type,
+					 const char *dataid);
+char * phonemgr_listener_put_data	(PhonemgrListener *l,
+					 PhonemgrListenerDataType type,
+					 const char *data);
+
 gboolean phonemgr_listener_connected	(PhonemgrListener *listener);
 
 /* Error types */
