@@ -22,7 +22,6 @@
 #include <glib/gi18n.h>
 #include <stdlib.h>
 #include <gtk/gtk.h>
-#include <gtkspell/gtkspell.h>
 #include <canberra-gtk.h>
 #include <time.h>
 #include <string.h>
@@ -322,7 +321,6 @@ send_message (GtkWidget *w, GtkBuilder *ui)
 void
 create_send_dialog (MyApp *app, GtkDialog *parent, const char *recip)
 {
-        GError *err = NULL;
 	GtkTextBuffer *buf;
 	GtkTextView *view;
 	GtkEntry *entry;
@@ -343,11 +341,6 @@ create_send_dialog (MyApp *app, GtkDialog *parent, const char *recip)
 	buf = gtk_text_view_get_buffer (view);
 	gtk_text_buffer_set_text (buf, "", 0);
 
-        if (!gtkspell_new_attach (view, NULL, &err)) {
-        	g_warning ("Couldn't initialise spell checking: %s", err->message);
-                g_error_free (err);
-        }
-
 	entry = GTK_ENTRY (gtk_builder_get_object (ui, "recipient"));
 	if (recip)
 		gtk_entry_set_text (entry, recip);
@@ -451,12 +444,6 @@ ui_init (MyApp *app)
 				    "active");
 
 	/* And the address chooser */
-	/* XXX Force a value to the device property else if there is no valid value in gconf
-	   and the Bluetooth chooser button won't show any label
-	 */
-	g_object_set (G_OBJECT (gtk_builder_get_object (app->ui, "btchooser")),
-		      "device", NULL,
-		      NULL);
 	gconf_bridge_bind_property (bridge,
 				    CONFBASE"/bluetooth_addr",
 				    G_OBJECT (gtk_builder_get_object (app->ui, "btchooser")),
